//
//  BitbucketAPIClient.h
//  BitbucketAPI
//
//  Created by Patrick Dinger on 07.02.13.
//  Copyright (c) 2013 Fournova GmbH. All rights reserved.
//

#import <Foundation/Foundation.h>

@class BitbucketAPICredentials;
@class BitbucketAPIRequest;
@class BitbucketAPIResponse;
@class BitbucketAPIRequestOperation;
@class BitbucketAPIUser;
@class BitbucketAPIRepository;
@class BitbucketAPIGroup;
@class BitbucketAPIComment;
@class BitbucketAPIPullRequest;
@class BitbucketAPIPullRequestCreationInfo;
@class BitbucketAPIPullRequestUpdateInfo;
@interface BitbucketAPIClient : NSObject
@property (nonatomic) BitbucketAPICredentials *credentials;
@property (nonatomic) NSString *userAgentString;

+ (instancetype)clientWithCredentials:(BitbucketAPICredentials *)credentials;
- (instancetype)initWithCredentials:(BitbucketAPICredentials *)credentials;

/** @name Enqueuing and Executing API Requests */

- (BitbucketAPIRequest *)enqueueRequest:(BitbucketAPIRequestOperation *)request completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;

- (void)cancelAllRequests;
- (NSArray *)allRequests;

/** @name Executing User API Requests */

- (BitbucketAPIRequest *)fetchCurrentUserWithCompletionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;
- (BitbucketAPIRequest *)fetchUserForUsername:(NSString *)username completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;

/** @name Executing Repository API Requests */

- (BitbucketAPIRequest *)fetchAllRepositoriesWithPaginationURL:(NSURL *)paginationURL completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;
- (BitbucketAPIRequest *)fetchAllRepositoriesForCurrentUserWithOptions:(NSDictionary *)options completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;
- (BitbucketAPIRequest *)fetchAllRepositoriesForUserWithUsername:(NSString *)username options:(NSDictionary *)options completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;
- (BitbucketAPIRequest *)fetchAllRepositoriesForTeamWithTeamName:(NSString *)teamName options:(NSDictionary *)options completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;

- (BitbucketAPIRequest *)fetchRepositoryWithName:(NSString *)repositoryName forUserWithUsername:(NSString *)username completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;

- (BitbucketAPIRequest *)createRepository:(BitbucketAPIRepository *)repository completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;
- (BitbucketAPIRequest *)createRepository:(BitbucketAPIRepository *)repository forUserWithName:(NSString *)username completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;

/** @name Executing Team API Requests */

- (BitbucketAPIRequest *)fetchTeamWithTeamName:(NSString *)teamName completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;
- (BitbucketAPIRequest *)fetchAllTeamsForCurrentUserWithOptions:(NSDictionary *)options completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;

/** @name Executing Pull Request API Requests */

- (BitbucketAPIRequest *)fetchAllPullRequestsForUserWithName:(NSString *)username repositoryName:(NSString *)repositoryName options:(NSDictionary *)options completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;
- (BitbucketAPIRequest *)fetchAllPullRequestsWithPaginationURL:(NSURL *)paginationURL completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;

- (BitbucketAPIRequest *)fetchPullRequestForUserWithName:(NSString *)username repositoryName:(NSString *)repositoryName pullRequestID:(NSNumber *)pullRequestID options:(NSDictionary *)options completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;
- (BitbucketAPIRequest *)createPullRequestForUserWithName:(NSString *)username repositoryName:(NSString *)repositoryName pullRequestCreationInfo:(BitbucketAPIPullRequestCreationInfo *)pullRequestCreationInfo completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;
- (BitbucketAPIRequest *)mergePullRequestForUserWithName:(NSString *)username repositoryName:(NSString *)repositoryName pullRequestID:(NSNumber *)pullRequestID options:(NSDictionary *)options completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;
- (BitbucketAPIRequest *)closePullRequestForUserWithName:(NSString *)username repositoryName:(NSString *)repositoryName pullRequestID:(NSNumber *)pullRequestID completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;
- (BitbucketAPIRequest *)editPullRequestForUserWithName:(NSString *)username repositoryName:(NSString *)repositoryName pullRequestID:(NSNumber *)pullRequestID pullRequestUpdateInfo:(BitbucketAPIPullRequestUpdateInfo *)pullRequestUpdateInfo completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;

/** @name Executing Pull Request Comment API Requests */

- (BitbucketAPIRequest *)fetchAllCommentsForUserWithName:(NSString *)username repositoryName:(NSString *)repositoryName pullRequestID:(NSNumber *)pullRequestID options:(NSDictionary *)options completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;
- (BitbucketAPIRequest *)fetchAllCommentsWithPaginationURL:(NSURL *)paginationURL completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;
- (BitbucketAPIRequest *)createCommentForUserWithName:(NSString *)username repositoryName:(NSString *)repositoryName pullRequestID:(NSNumber *)pullRequestID parentCommentID:(NSNumber *)parentCommentID body:(NSString *)body completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;
- (BitbucketAPIRequest *)editCommentForUserWithName:(NSString *)username repositoryName:(NSString *)repositoryName pullRequestID:(NSNumber *)pullRequestID commentID:(NSNumber *)commentID body:(NSString *)body completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;
- (BitbucketAPIRequest *)deleteCommentForUserWithName:(NSString *)username repositoryName:(NSString *)repositoryName pullRequestID:(NSNumber *)pullRequestID commentID:(NSNumber *)commentID completionHandler:(void (^)(BitbucketAPIResponse *response))completionHandler;

@end
